==> pipewire-docs-1%3A0.3.34-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/stream_8c.js <==
var stream_8c =
[
    [ "buffer", "structbuffer.html", "structbuffer" ],
    [ "queue", "structqueue.html", "structqueue" ],
    [ "data", "structdata.html", "structdata" ],
    [ "param", "structparam.html", "structparam" ],
    [ "control", "structcontrol.html", "structcontrol" ],
    [ "stream", "structstream.html", "structstream" ],
    [ "BUFFER_FLAG_ADDED", "stream_8c.html#a25f4ab4c169e3fef470936e39ba6126f", null ],
    [ "BUFFER_FLAG_MAPPED", "stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2", null ],
    [ "BUFFER_FLAG_QUEUED", "stream_8c.html#a89bba79201856c41ea53bd01e65f6438", null ],
    [ "IDX_Buffers", "stream_8c.html#a20bc42a8212e902b5aca2c4a89a9791e", null ],
    [ "IDX_EnumFormat", "stream_8c.html#a6403e2fb0c6cf90f26a8f3f93fb75b4e", null ],
    [ "IDX_Format", "stream_8c.html#a114980481aa2e305cced169634b43baf", null ],
    [ "IDX_IO", "stream_8c.html#a624541240740aec600b0f13102e92b23", null ],
    [ "IDX_Latency", "stream_8c.html#a6bf50395ab8eb02b49ca03051ebda8ca", null ],
    [ "IDX_Meta", "stream_8c.html#ada9d2a0ba9c7d74575127151112ddd63", null ],
    [ "IDX_Props", "stream_8c.html#aebee6de53867abaf97036f1750b12a17", null ],
    [ "MASK_BUFFERS", "stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc", null ],
    [ "MAX_BUFFERS", "stream_8c.html#a7781bc9613ec655352585fb1bac2595d", null ],
    [ "MAX_PORTS", "stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764", null ],
    [ "N_NODE_PARAMS", "stream_8c.html#aa561250559f89a088c810830e5cced58", null ],
    [ "N_PORT_PARAMS", "stream_8c.html#add235ea984f258de72ca6469f8a9808e", null ],
    [ "NAME", "stream_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PARAM_FLAG_LOCKED", "stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0", null ],
    [ "pw_stream_add_listener", "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_connect", "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54", null ],
    [ "pw_stream_dequeue_buffer", "group__pw__stream.html#gab2ef0e28a1e91816f8015ef9814d18f7", null ],
    [ "pw_stream_destroy", "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891", null ],
    [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
    [ "pw_stream_flush", "group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97", null ],
    [ "pw_stream_get_control", "stream_8c.html#a52d3a718a1171132c69f2a4f2ca6efdc", null ],
    [ "pw_stream_get_core", "group__pw__stream.html#gaeb58b45b3e0d8fa804e9165d32159aa2", null ],
    [ "pw_stream_get_name", "group__pw__stream.html#ga751f41a0a5ce1ece31ec126b3cab4fd4", null ],
    [ "pw_stream_get_node_id", "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053", null ],
    [ "pw_stream_get_properties", "group__pw__stream.html#gafc74d20ae2305d82aba860fde41b9e31", null ],
    [ "pw_stream_get_state", "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
    [ "pw_stream_is_driving", "group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a", null ],
    [ "pw_stream_new", "group__pw__stream.html#ga35370932da668b23675d1fa4770fc094", null ],
    [ "pw_stream_new_simple", "group__pw__stream.html#ga7a8eafa174549733293f11ec2c646827", null ],
    [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_active", "group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba", null ],
    [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
    [ "pw_stream_set_error", "stream_8c.html#a9f4af21e4ea2691b7d4115fec30a5476", null ],
    [ "pw_stream_state_as_string", "group__pw__stream.html#gae91dbee70fbfed05786cc55fe337a98b", null ],
    [ "pw_stream_trigger_process", "group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21", null ],
    [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
    [ "pw_stream_update_properties", "group__pw__stream.html#ga065b067d55def0d2c2cedf814a5c55d0", null ]
];

==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/stream_8c.js <==
var stream_8c =
[
    [ "buffer", "structbuffer.html", "structbuffer" ],
    [ "queue", "structqueue.html", "structqueue" ],
    [ "data", "structdata.html", "structdata" ],
    [ "param", "structparam.html", "structparam" ],
    [ "control", "structcontrol.html", "structcontrol" ],
    [ "stream", "structstream.html", "structstream" ],
    [ "BUFFER_FLAG_ADDED", "stream_8c.html#a25f4ab4c169e3fef470936e39ba6126f", null ],
    [ "BUFFER_FLAG_MAPPED", "stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2", null ],
    [ "BUFFER_FLAG_QUEUED", "stream_8c.html#a89bba79201856c41ea53bd01e65f6438", null ],
    [ "IDX_Buffers", "stream_8c.html#a20bc42a8212e902b5aca2c4a89a9791e", null ],
    [ "IDX_EnumFormat", "stream_8c.html#a6403e2fb0c6cf90f26a8f3f93fb75b4e", null ],
    [ "IDX_Format", "stream_8c.html#a114980481aa2e305cced169634b43baf", null ],
    [ "IDX_IO", "stream_8c.html#a624541240740aec600b0f13102e92b23", null ],
    [ "IDX_Latency", "stream_8c.html#a6bf50395ab8eb02b49ca03051ebda8ca", null ],
    [ "IDX_Meta", "stream_8c.html#ada9d2a0ba9c7d74575127151112ddd63", null ],
    [ "IDX_Props", "stream_8c.html#aebee6de53867abaf97036f1750b12a17", null ],
    [ "MASK_BUFFERS", "stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc", null ],
    [ "MAX_BUFFERS", "stream_8c.html#a7781bc9613ec655352585fb1bac2595d", null ],
    [ "MAX_PORTS", "stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764", null ],
    [ "N_NODE_PARAMS", "stream_8c.html#aa561250559f89a088c810830e5cced58", null ],
    [ "N_PORT_PARAMS", "stream_8c.html#add235ea984f258de72ca6469f8a9808e", null ],
    [ "NAME", "stream_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PARAM_FLAG_LOCKED", "stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0", null ],
    [ "pw_stream_add_listener", "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_connect", "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54", null ],
    [ "pw_stream_dequeue_buffer", "group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94", null ],
    [ "pw_stream_destroy", "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891", null ],
    [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
    [ "pw_stream_flush", "group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97", null ],
    [ "pw_stream_get_control", "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7", null ],
    [ "pw_stream_get_core", "group__pw__stream.html#gaf98d3941e1f3343c61dc218296eb8942", null ],
    [ "pw_stream_get_name", "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0", null ],
    [ "pw_stream_get_node_id", "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053", null ],
    [ "pw_stream_get_properties", "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b", null ],
    [ "pw_stream_get_state", "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
    [ "pw_stream_is_driving", "group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a", null ],
    [ "pw_stream_new", "group__pw__stream.html#ga712ca485dc634252d144556074980f0a", null ],
    [ "pw_stream_new_simple", "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11", null ],
    [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_active", "group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba", null ],
    [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
    [ "pw_stream_set_error", "stream_8c.html#a9f4af21e4ea2691b7d4115fec30a5476", null ],
    [ "pw_stream_state_as_string", "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4", null ],
    [ "pw_stream_trigger_process", "group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21", null ],
    [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
    [ "pw_stream_update_properties", "group__pw__stream.html#ga065b067d55def0d2c2cedf814a5c55d0", null ]
];
